@@ -111,7 +111,7 @@ Flags:
 			dst := filepath.Join(ctx.Projectdir(), "vendor", "src", filepath.FromSlash(dep.Importpath))
 			src := filepath.Join(wc.Dir(), dep.Path)
 
-			if err := vendor.Copypath(dst, src); err != nil {
+			if err := fileutils.Copypath(dst, src); err != nil {
 				return err
 			}
 
