@@ -821,7 +821,7 @@ func helloworld() {
 }
 
 // test that compiling A in test scope compiles B in regular scope
-func TestTestDepdenantPackage(t *testing.T) {
+func TestTestDependantPackage(t *testing.T) {
 	gb := T{T: t}
 	defer gb.cleanup()
 	gb.tempDir("src")
@@ -871,6 +871,27 @@ func TestTest(t *testing.T) {
 	gb.mustNotExist(filepath.Join(gb.tempdir, "pkg")) // ensure no pkg directory is created
 }
 
+func TestTestPackageNopeMode(t *testing.T) {
+	gb := T{T: t}
+	defer gb.cleanup()
+	gb.tempDir("src")
+	gb.tempDir("src/pkg1")
+	gb.tempFile("src/pkg1/pkg_test.go", `package pkg1
+import "testing"
+
+func TestTest(t *testing.T) {
+	t.Log("hello")
+}
+`)
+	gb.cd(gb.tempdir)
+	tmpdir := gb.tempDir("tmp")
+	gb.setenv("TMP", tmpdir)
+	gb.run("test", "-n", "pkg1")
+	gb.grepStdout("^pkg1$", `expected "pkg1"`)
+	gb.mustBeEmpty(tmpdir)
+	gb.mustNotExist(filepath.Join(gb.tempdir, "pkg")) // ensure no pkg directory is created
+}
+
 func TestTestPackageFailedToBuild(t *testing.T) {
 	gb := T{T: t}
 	defer gb.cleanup()
@@ -1351,7 +1372,9 @@ func TestRaceMapRW(t *testing.T) {
 	tmpdir := gb.tempDir("tmp")
 	gb.setenv("TMP", tmpdir)
 	gb.runFail("test", "-race")
-	gb.grepStderr(regexp.QuoteMeta(fmt.Sprintf("FATAL: go installation at %s is missing race support", runtime.GOROOT())), "expected missing race support message")
+	raceError1 := fmt.Sprintf("FATAL: go installation at %s is missing race support", runtime.GOROOT())
+	raceError2 := fmt.Sprintf("FATAL: race detector not supported on %s/%s", runtime.GOOS, runtime.GOARCH)
+	gb.grepStderr(regexp.QuoteMeta(raceError1)+"|"+regexp.QuoteMeta(raceError2), "expected missing race support message")
 	gb.mustBeEmpty(tmpdir)
 }
 
@@ -1618,3 +1641,54 @@ func main() {
 	gb.mustBeEmpty(tmpdir)
 	gb.grepStderr(`FATAL: command "build" failed: failed to resolve import path "x": import "this/is/a/bad/path": not found`, "expected FATAL")
 }
+
+func TestIssue530(t *testing.T) {
+	gb := T{T: t}
+	defer gb.cleanup()
+
+	gb.tempDir("src/main")
+	gb.tempFile("src/main/main.go", `package main
+
+import "fmt"
+
+func main() {
+	fmt.Println("hello gb")
+}
+`)
+
+	gb.cd(gb.tempdir)
+	tmpdir := gb.tempDir("tmp")
+	gb.run("build")
+	gb.mustBeEmpty(tmpdir)
+}
+
+// goconvey (and probably others) do not parse flags passed to the
+// test binary, they just expect them to be present in their raw form
+// in os.Args. As such -test.v and -test.v=true are not the same.
+// Assert that gb is passing the latter form.
+func TestIssue605(t *testing.T) {
+	gb := T{T: t}
+	defer gb.cleanup()
+
+	gb.tempDir("src/issue605")
+	gb.tempFile("src/issue605/issue_test.go", `package issue605
+
+import (
+        "os"
+        "testing"
+)
+
+func TestFlags(t *testing.T) {
+        for _, f := range os.Args {
+                if f == "-test.v=true" {
+                        return
+                }
+        }
+        t.Fatalf("could not find test flag: %q", os.Args)
+}`)
+	gb.cd(gb.tempdir)
+	tmpdir := gb.tempDir("tmp")
+	gb.run("test", "-v") // should translate into -test.v=true
+	gb.mustBeEmpty(tmpdir)
+
+}
