@@ -22,11 +22,7 @@ func FindProjectroot(path string) (string, error) {
 			}
 			return "", err
 		}
-		path, err := filepath.EvalSymlinks(path)
-		if err != nil {
-			return "", err
-		}
 		return path, nil
 	}
-	return "", fmt.Errorf("could not find project root in %q or its parents", start)
+	return "", fmt.Errorf(`could not find project root in "%s" or its parents`, start)
 }
