@@ -5,15 +5,13 @@
 package gb
 
 import (
-	"fmt"
-	"io"
+	"go/build"
 	"os"
 	"path/filepath"
-	"strings"
-
-	"github.com/constabulary/gb/debug"
 )
 
+var releaseTags = build.Default.ReleaseTags
+
 // Toolchain represents a standardised set of command line tools
 // used to build and test Go programs.
 type Toolchain interface {
@@ -68,34 +66,21 @@ func mkdir(path string) error {
 	return os.MkdirAll(path, 0755)
 }
 
-func copyfile(dst, src string) error {
-	err := mkdir(filepath.Dir(dst))
-	if err != nil {
-		return fmt.Errorf("copyfile: mkdirall: %v", err)
-	}
-	r, err := os.Open(src)
-	if err != nil {
-		return fmt.Errorf("copyfile: open(%q): %v", src, err)
-	}
-	defer r.Close()
-	w, err := os.Create(dst)
-	if err != nil {
-		return fmt.Errorf("copyfile: create(%q): %v", dst, err)
-	}
-	defer w.Close()
-	debug.Debugf("copyfile(dst: %v, src: %v)", dst, src)
-	_, err = io.Copy(w, r)
-	return err
-}
-
-// joinlist joins a []string representing path items
-// using the operating system specific list separator.
-func joinlist(l []string) string {
-	return strings.Join(l, string(filepath.ListSeparator))
-}
-
 // stripext strips the extension from a filename.
 // The extension is defined by filepath.Ext.
 func stripext(path string) string {
 	return path[:len(path)-len(filepath.Ext(path))]
 }
+
+func relImportPath(root, path string) (string, error) {
+	if isRel(path) {
+		return filepath.Rel(root, path)
+	}
+	return path, nil
+}
+
+// isRel returns if an import path is relative or absolute.
+func isRel(path string) bool {
+	// TODO(dfc) should this be strings.StartsWith(".")
+	return path == "."
+}
